@@ -4,10 +4,9 @@ import os
 import platform
 
 # Need to append all the python subdirectories because Python doesn't recognize them
-sys.path.append(os.path.abspath('.'))
-sys.path.append(os.path.abspath(__file__))
-print(os.path.abspath('.'))
-print(os.path.abspath(__file__))
+sys.path.append(os.path.abspath(os.path.dirname(__file__)))
+
+
 # Import the necessary library depending on the OS
 if platform.system() == 'Linux':
     import linux_menus
